import React, { memo } from 'react';
import { Image, ImageBackground, ScrollView, Text, TouchableOpacity, View, } from 'react-native';
import Animated from 'react-native-reanimated';
import { Header, StickyHeader } from './components';
import { data, FOLLOWERS, Strings } from './constants';
import { useParallaxHeader } from './hooks';
import styles from './styles';
const AnimatedScrollView = Animated.createAnimatedComponent(ScrollView);
const RenderCards = ({ value, index }) => {
    return (React.createElement(View, { style: styles.cardContainer, key: index },
        React.createElement(View, { style: styles.card },
            React.createElement(View, { style: styles.profileContainerStyle },
                React.createElement(Image, { style: styles.image, source: { uri: value.photo } }),
                React.createElement(Text, { style: styles.name }, FOLLOWERS[2].name)),
            React.createElement(View, { style: styles.descriptionStyle },
                value.image ? (React.createElement(ImageBackground, { source: value.image, borderRadius: 10, style: styles.imageBackgroundStyle, resizeMode: 'stretch' })) : null,
                React.createElement(Text, { numberOfLines: 5, ellipsizeMode: 'tail', style: styles.textDescriptionStyle }, Strings.LOREM),
                React.createElement(View, { style: styles.hashtagTextViewStyle },
                    React.createElement(TouchableOpacity, null,
                        React.createElement(Text, { style: styles.hashtagTextStyle }, "#React-Native")),
                    React.createElement(TouchableOpacity, null,
                        React.createElement(Text, { style: styles.hashtagTextStyle }, "#Android")),
                    React.createElement(TouchableOpacity, null,
                        React.createElement(Text, { style: styles.hashtagTextStyle }, "#IOS")))))));
};
const ParallaxHeader = ({ renderHeader, renderStickyHeader, stickyHeaderTitle, children, }) => {
    const { scrollRef, handleHeaderLayout, scrollHandler, sharedProps, headerContainerStyle, collapsedOverlayStyle, } = useParallaxHeader();
    return (React.createElement(View, { style: styles.container },
        React.createElement(Animated.View, { onLayout: handleHeaderLayout, style: headerContainerStyle }, !renderHeader ? React.createElement(Header, null) : React.createElement(Header, null, renderHeader())),
        React.createElement(Animated.View, { style: collapsedOverlayStyle }, !renderStickyHeader ? (React.createElement(StickyHeader, { name: stickyHeaderTitle })) : (React.createElement(StickyHeader, null, renderStickyHeader()))),
        React.createElement(AnimatedScrollView, { ref: scrollRef, onScroll: scrollHandler, showsVerticalScrollIndicator: false, ...sharedProps }, !children
            ? data.map((value, _index) => (React.createElement(RenderCards, { value: value, index: _index })))
            : children)));
};
export default memo(ParallaxHeader);
//# sourceMappingURL=ParallaxHeader.js.map