import { createMaterialTopTabNavigator, } from '@react-navigation/material-top-tabs';
import React, { memo, useCallback, useEffect } from 'react';
import { View } from 'react-native';
import Animated from 'react-native-reanimated';
import { DefaultItem, Header, StickyHeader, TabBar } from './components';
import AnimatedFlatList from './components/AnimatedFlatList';
import { FOLLOWERS, FOLLOWING } from './constants/DummyData';
import { useParallaxHeaderWithTab } from './hooks';
import styles from './styles';
const Tab = createMaterialTopTabNavigator();
// default renderItems for tabs
const renderDefault = ({ item }) => (React.createElement(DefaultItem, { items: item }));
// default tabs array with some data
const defaultTabs = [
    {
        title: 'Followers',
        data: FOLLOWERS,
        renderTabContent: renderDefault,
    },
    {
        title: 'Following',
        data: FOLLOWING,
        renderTabContent: renderDefault,
    },
];
const ParallaxHeaderWithTab = ({ renderHeader, renderStickyHeader, screenOptions, onTabChange, backBehavior, tabBarPosition, initialRouteName, tabs = defaultTabs, }) => {
    const { tabsHandlers, tabIndex, handleHeaderLayout, sharedProps, setTabIndex, tabBarStyle, headerContainerStyle, collapsedOverlayStyle, } = useParallaxHeaderWithTab(tabs);
    useEffect(() => {
        onTabChange ? onTabChange({ tabIndex }) : null;
    }, [onTabChange, tabIndex]);
    const renderTabs = tabsHandlers.map(useCallback((tabHandler, _index) => (React.createElement(AnimatedFlatList, { ref: tabHandler === null || tabHandler === void 0 ? void 0 : tabHandler.tabRef, data: tabHandler === null || tabHandler === void 0 ? void 0 : tabHandler.data, renderTabContent: ({ item }) => tabHandler === null || tabHandler === void 0 ? void 0 : tabHandler.renderTabContent({ item }), onScroll: tabHandler.tabScrollHandler, showsVerticalScrollIndicator: false, ...tabHandler === null || tabHandler === void 0 ? void 0 : tabHandler.renderFlatListProps, ...sharedProps })), [sharedProps]));
    const renderTabBar = useCallback((props) => (React.createElement(Animated.View, { style: tabBarStyle },
        React.createElement(TabBar, { onIndexChange: setTabIndex, ...props }))), [tabBarStyle, setTabIndex]);
    return (React.createElement(View, { style: styles.container },
        React.createElement(Animated.View, { onLayout: handleHeaderLayout, style: headerContainerStyle }, !renderHeader ? React.createElement(Header, null) : React.createElement(Header, null, renderHeader())),
        React.createElement(Animated.View, { style: collapsedOverlayStyle }, !renderStickyHeader ? (React.createElement(StickyHeader, null)) : (React.createElement(StickyHeader, null, renderStickyHeader()))),
        React.createElement(Tab.Navigator, { tabBar: renderTabBar, screenOptions: screenOptions, backBehavior: backBehavior, tabBarPosition: tabBarPosition, initialRouteName: initialRouteName }, tabs.map((tab, index) => (React.createElement(Tab.Screen, { name: tab === null || tab === void 0 ? void 0 : tab.title, options: tab === null || tab === void 0 ? void 0 : tab.tabOptions }, () => renderTabs[index]))))));
};
export default memo(ParallaxHeaderWithTab);
//# sourceMappingURL=ParallaxHeaderWithTab.js.map